#!/usr/bin/env perl

use strict;
use warnings;

use Test::More tests => 1;

use_ok( 'CatalystX::Widget::Paginator' );

diag( "Testing CatalystX::Widget::Paginator $CatalystX::Widget::Paginator::VERSION, Perl $], $^X" );

